@@ -12,7 +12,6 @@ from drf_auth_service.authentication.serializers import CustomTokenRefreshSerial
     ReturnRegisterSerializer, ReturnAccessTokenSerializer
 from drf_auth_service.common.managers import BaseManager
 from drf_auth_service.common.mixins import GenericEBSViewSet
-from drf_auth_service.common.permissions import ServiceTokenPermission
 from drf_auth_service.common.register_backends import RegisterManager
 from drf_auth_service.settings import settings
 
@@ -86,7 +85,7 @@ class AuthenticationViewSet(GenericEBSViewSet):
 
 class LoginViewSet(TokenViewBase):
     serializer_class = settings.SERIALIZERS.LOGIN_SERIALIZER
-    permission_classes = (ServiceTokenPermission,)
+    permission_classes = (settings.PERMISSIONS.SERVICE_TOKEN_PERMISSION,)
 
     @swagger_auto_schema(request_body=settings.SERIALIZERS.LOGIN_SERIALIZER, responses={200: jwt_response})
     def post(self, request, *args, **kwargs):
@@ -106,7 +105,7 @@ class LoginViewSet(TokenViewBase):
 
 class EBSTokenRefreshView(TokenViewBase):
     serializer_class = CustomTokenRefreshSerializer
-    permission_classes = (ServiceTokenPermission,)
+    permission_classes = (settings.PERMISSIONS.SERVICE_TOKEN_PERMISSION,)
 
     @swagger_auto_schema(request_body=CustomTokenRefreshSerializer, responses={200: refresh_response})
     def post(self, request, *args, **kwargs):
