@@ -140,7 +140,7 @@ class ActivationCode(models.Model):
     @staticmethod
     def create_token(user, key_type, for_phone=False):
         from drf_auth_service.settings import settings
-        if settings.DEBUG_MODE:
+        if settings.DEBUG_MODE and user.register_type in [RegisterType.PHONE_NUMBER, RegisterType.PHONE_NUMBER_CODE]:
             token = ActivationCode(key=settings.DEBUG_KEY)
         else:
             password_reset_token_validation_time = 24
