@@ -6,7 +6,6 @@ from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
 from six import text_type
 from social_django.utils import load_strategy
 
-from drf_auth_service.common.permissions import ServiceTokenPermission
 from drf_auth_service.models import SSOUser
 from drf_auth_service.settings import settings
 from drf_auth_service.socials.helpers import get_user_data_from_provider
@@ -17,7 +16,7 @@ oauth_response = openapi.Response('Respond with jwt secret token if user exists'
 
 @swagger_auto_schema(method='POST', request_body=SocialSerializer, responses={200: oauth_response})
 @api_view(['POST'])
-@permission_classes([ServiceTokenPermission])
+@permission_classes([settings.PERMISSIONS.SERVICE_TOKEN_PERMISSION])
 def social_login(self, request):
     """Authenticate user through the provider(facebook/google/apple) and access_token"""
 
