@@ -115,7 +115,7 @@ class UserViewSet(
             if self.action == 'list':
                 return super().get_queryset().filter(
                     service=self.request.service
-                ).select_related('user_social_identifier')
+                ).prefetch_related('user_social_identifier')
 
             return super().get_queryset().filter(service=self.request.service)
         return super().get_queryset()
